=========================
 Invenio-Comments v0.1.1
=========================

Invenio-Comments v0.1.1 was released on July 31, 2015.

About
-----

Invenio module that adds record commenting feature.

*This is an experimental development preview release.*

Bug fixes
---------

- Adds dependency to invenio-accounts and fixes affected imports.

Installation
------------

   $ pip install invenio-comments==0.1.1

Documentation
-------------

   http://invenio-comments.readthedocs.org/en/v0.1.1

Happy hacking and thanks for flying Invenio-Comments.

| Invenio Development Team
|   Email: info@invenio-software.org
|   IRC: #invenio on irc.freenode.net
|   Twitter: http://twitter.com/inveniosoftware
|   GitHub: https://github.com/inveniosoftware/invenio-comments
|   URL: http://invenio-software.org
